@@ -1,5 +1,5 @@
 package Docker::CLI::Wrapper::Container;
-$Docker::CLI::Wrapper::Container::VERSION = '0.0.3';
+$Docker::CLI::Wrapper::Container::VERSION = '0.0.4';
 use strict;
 use warnings;
 use 5.014;
@@ -41,6 +41,31 @@ sub run_docker
     return;
 }
 
+sub exe
+{
+    my ( $self, $args ) = @_;
+
+    my @user;
+    if ( exists $args->{user} )
+    {
+        push @user, ( '--user', $args->{user} );
+    }
+
+    return $self->docker(
+        { cmd => [ 'exec', @user, $self->container(), @{ $args->{cmd} } ] } );
+}
+
+sub exe_bash_code
+{
+    my ( $self, $args ) = @_;
+
+    return $self->exe(
+        {
+            %$args, cmd => [ 'bash', '-c', $args->{code}, ],
+        }
+    );
+}
+
 1;
 
 __END__
@@ -55,7 +80,7 @@ Docker::CLI::Wrapper::Container - manage a container.
 
 =head1 VERSION
 
-version 0.0.3
+version 0.0.4
 
 =head1 SYNOPSIS
 
@@ -91,6 +116,19 @@ Get the container to run (after pulling its system).
 
 Stops and deletes the container.
 
+=head2 $obj->exe({ cmd => [@CMD], })
+
+"docker exec"s the @CMD on the container: one can specify
+an optional 'user' username.
+
+[Added in version 0.0.4.]
+
+=head2 $obj->exe_bash_code({code => $CODE})
+
+Runs $CODE using C<'bash -c'> inside the container.
+
+[Added in version 0.0.4.]
+
 =head2 $obj->do_system({ cmd => [@CMD]});
 
 Sugar for system(@CMD) - prints and dies on error.
